define(
//begin v1.x content
{
	"scientificFormat": "#E0",
	"infinity": "∞",
	"superscriptingExponent": "×",
	"list": ";",
	"percentSign": "%",
	"minusSign": "-",
	"decimalFormat-short": "000 бил'.'",
	"nan": "NaN",
	"plusSign": "+",
	"currencyFormat": "#,##0.00 ¤;(#,##0.00 ¤)",
	"perMille": "‰",
	"group": ".",
	"percentFormat": "#,##0%",
	"decimalFormat-long": "000 билиона",
	"decimalFormat": "#,##0.###",
	"currencyFormat-short": "000 бил'.' ¤",
	"timeSeparator": ".",
	"decimal": ",",
	"exponential": "E"
}
//end v1.x content
);